# Read data =============================
d <- read.table("survival.txt", header = TRUE)
survival <- d$survival
age <- d$age 
female <- d$female 
# =======================================







# descriptive statistics ================
df.total <- aggregate(data.frame(survival = survival), list(female = female), length)
df.survival <- aggregate(data.frame(survival = survival), list(female = female), sum)
sur.female <- data.frame(female = df.survival$female, survival = df.survival$survival, total = df.total$survival)
cbind(sur.female, sur.rate = sur.female$survival / sur.female$total)

age.class <- floor(age / 10)
df.total <- aggregate(data.frame(survival = survival), list(age.class = age.class), length)
df.survival <- aggregate(data.frame(survival = survival), list(age.class = age.class), sum)
sur.age <- data.frame(age.class = df.survival$age.class, survival = df.survival$survival, total = df.total$survival)
cbind(sur.age, sur.rate = sur.age$survival / sur.age$total)
# =======================================











# ordinary regression ====================
fitWrong <- lm(survival ~ age + female)
summary(fitWrong)
# ========================================

# the plot =================
pred.male <- predict(fitWrong, newdata = data.frame(age = 0:80, female = rep(0, 81)))
pred.female <- predict(fitWrong, newdata = data.frame(age = 0:80, female = rep(1, 81)))

plot(age[female == 0], survival[female == 0], col = 4, xlim = c(0, 80), ylim = c(-0.1, 1.1), xlab = "age", ylab = "survival")
points(age[female == 1], survival[female == 1], col = 2, pch = 3)
lines(pred.male , col = 4, lty = 2)
lines(pred.female , col = 2, lty = 2)
legend(53, 1.1, c("female true", "male true", "female fitted", "male fitted"), 
  lty = c(-1, -1, 2, 2), col = c(2, 4, 2, 4), pch = c(3, 1, -1, -1))
# ===========================







# logistic regression =======================
fitRight <- glm(survival ~ age + female, binomial)
summary(fitRight)
# ===========================================

# the plot =================
y.male <- predict(fitRight, newdata = data.frame(age = 0:80, female = rep(0, 81)))
pi.male <- exp(y.male) / (1 + exp(y.male))
y.female <- predict(fitRight, newdata = data.frame(age = 0:80, female = rep(1, 81)))
pi.female <- exp(y.female) / (1 + exp(y.female))

plot(age[female == 0], survival[female == 0], col = 4, xlim = c(0, 80), ylim = c(-0.1, 1.1), xlab = "age", ylab = "survival")
points(age[female == 1], survival[female == 1], col = 2, pch = 3)
lines(pi.male, col = 4)
lines(pi.female, col = 2)
legend(53, 1.1, c("female true", "male true", "female fitted", "male fitted"), 
  lty = c(-1, -1, 1, 1), col = c(2, 4, 2, 4), pch = c(3, 1, -1, -1))
# ===========================

# combining the two plots ================
pred.male <- predict(fitWrong, newdata = data.frame(age = 0:80, female = rep(0, 81)))
pred.female <- predict(fitWrong, newdata = data.frame(age = 0:80, female = rep(1, 81)))
y.male <- predict(fitRight, newdata = data.frame(age = 0:80, female = rep(0, 81)))
pi.male <- exp(y.male) / (1 + exp(y.male))
y.female <- predict(fitRight, newdata = data.frame(age = 0:80, female = rep(1, 81)))
pi.female <- exp(y.female) / (1 + exp(y.female))

plot(age[female == 0], survival[female == 0], col = 4, xlim = c(0, 80), ylim = c(-0.1, 1.1), xlab = "age", ylab = "survival")
points(age[female == 1], survival[female == 1], col = 2, pch = 3)
lines(pred.male , col = 4, lty = 2)
lines(pred.female , col = 2, lty = 2)
lines(pi.male, col = 4)
lines(pi.female, col = 2)
legend(49, 1.1, c("female true", "male true", "female ordinary", "male ordinary", "female logistic", "male logistic"), 
  lty = c(-1, -1, 2, 2, 1, 1), col = c(2, 4, 2, 4, 2, 4), pch = c(3, 1, -1, -1, -1, -1))
# ========================================









# model selection =======================
fit.1 <- glm(survival ~ age, binomial)
summary(fit.1) 

fit.2 <- glm(survival ~ female, binomial)
summary(fit.2) 

ageSq <- age^2
fit.3 <- glm(survival ~ age + ageSq, binomial)
summary(fit.3)

fit.4 <- glm(survival ~ age + female, binomial)
summary(fit.4) 

fit.5 <- glm(survival ~ age * female, binomial)
summary(fit.5) 
# =======================================



